FixedHeader examples - Initialisation and options

# FixedHeader example Initialisation and options

The following examples show how FixedHeader can be enabled on a DataTable and its various options used.

### Initialisation and options

- Basic initialisation
- Header and footer fixed
- Multiple tables
- Offset - automatic
- Offset - manual
- Horizontal page scrolling
- Enable / disable FixedHeader
- Show / hide FixedHeader
- Alternative initialisation

Please refer to the DataTables documentation for full information about its API properties and methods.
Additionally, there are a wide range of extensions and plug-ins which extend the capabilities of DataTables.

DataTables designed and created by SpryMedia Ltd © 2007-2016
DataTables is licensed under the MIT license.